@@ -1,6 +1,6 @@
 import datetime
 
-from MonsterLab import Random
+from MonsterLab.monster_data import Random
 
 
 class Monster:
